@@ -1,34 +1,29 @@
 function resu = vertcat(df, varargin) 
   
-  %% Copyright (C) 2009-2012 Pascal Dupuis <Pascal.Dupuis@uclouvain.be>
+  %% Copyright (C) 2009-2017 Pascal Dupuis <cdemills@gmail.com>
   %%
-  %% This file is part of Octave.
+  %% This file is part of the dataframe package for Octave.
   %%
-  %% Octave is free software; you can redistribute it and/or
+  %% This package is free software; you can redistribute it and/or
   %% modify it under the terms of the GNU General Public
   %% License as published by the Free Software Foundation;
-  %% either version 2, or (at your option) any later version.
+  %% either version 3, or (at your option) any later version.
   %%
-  %% Octave is distributed in the hope that it will be useful,
+  %% This package is distributed in the hope that it will be useful,
   %% but WITHOUT ANY WARRANTY; without even the implied
   %% warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
   %% PURPOSE.  See the GNU General Public License for more
   %% details.
   %%
   %% You should have received a copy of the GNU General Public
-  %% License along with Octave; see the file COPYING.  If not,
-  %% write to the Free Software Foundation, 51 Franklin Street -
-  %% Fifth Floor, Boston, MA 02110-1301, USA.
-
-  %#
-  %# $Id$
-  %#
+  %% License along with this package; see the file COPYING.  If not,
+  %% see <http://www.gnu.org/licenses/>.
 
   %# do the conversion now, in order not to loose inputnames
   for indi = (1:length (varargin))
     varargin{indi} = dataframe (varargin{indi}, 'colnames', inputname(1+indi));,
-  endfor
+  end
 
   resu = cat (1, df, varargin{:});
 
-endfunction
+end
